@@ -1,19 +1,36 @@
 /*
     This file is part of LibSyndication.
-    SPDX-FileCopyrightText: 2006 Frank Osterfeld <osterfeld@kde.org>
 
-    SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
+    Copyright (C) 2006 Frank Osterfeld <osterfeld@kde.org>
+
+    This program is free software; you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation; either version 2 of the License, or
+    (at your option) any later version.
+
+    This program is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with this program; if not, write to the Free Software
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+
+    As a special exception, permission is given to link this program
+    with any edition of Qt, and distribute the resulting executable,
+    without including the source code for Qt in the source distribution.
 */
 
+#include "specificdocument.h"
 #include "documentsource.h"
 #include "feed.h"
 #include "parsercollection.h"
-#include "specificdocument.h"
 
-#include <QByteArray>
 #include <QDebug>
-#include <QFile>
-#include <QString>
+#include <QtCore/QByteArray>
+#include <QtCore/QFile>
+#include <QtCore/QString>
 
 #include <iostream>
 
@@ -43,7 +60,7 @@ int main(int argc, char **argv)
 
     int pcompare = 2;
     if (argc < 2) {
-        printUsage(QStringLiteral("filename expected"));
+        printUsage(QLatin1String("filename expected"));
         return 1;
     }
 
@@ -53,7 +70,7 @@ int main(int argc, char **argv)
 
     if (filename == QLatin1String("--specific-format")) {
         if (argc < 3) {
-            printUsage(QStringLiteral("filename expected"));
+            printUsage(QLatin1String("filename expected"));
             return 1;
         }
         filename = QFile::decodeName(argv[2]);
@@ -63,42 +80,35 @@ int main(int argc, char **argv)
 
     QString expfname;
 
-    if (argc >= (pcompare + 1) //
-        && QString::fromLatin1(argv[pcompare]) == QLatin1String("--compare")) {
+    if (argc >= pcompare + 1 && QString::fromLatin1(argv[pcompare]) == QLatin1String("--compare")) {
         expfname = QString::fromLatin1(argv[pcompare + 1]);
     }
 
     QFile f(filename);
 
-    if (!f.open(QIODevice::ReadOnly | QIODevice::Text)) {
-        printUsage(QStringLiteral("Couldn't open file"));
+    if (!f.open(QIODevice::ReadOnly)) {
+        printUsage(QLatin1String("Couldn't open file"));
         return 1;
     }
 
-    DocumentSource src(f.readAll(), QStringLiteral("http://libsyndicationtest"));
+    DocumentSource src(f.readAll(), QLatin1String("http://libsyndicationtest"));
     f.close();
 
     FeedPtr ptr(Syndication::parse(src));
 
-    if (ptr == nullptr) {
+    if (ptr == 0L) {
         printUsage(QStringLiteral("Couldn't parse file: (%1)").arg(Syndication::parserCollection()->lastError()));
         return 1;
     }
 
     QString res = specificformat ? ptr->specificDocument()->debugInfo() : ptr->debugInfo();
-#if 0
-    QFile headerFile(QStringLiteral("/tmp/bb.txt"));
-    headerFile.open(QIODevice::WriteOnly | QIODevice::Text);
-    QTextStream outHeaderStream(&headerFile);
-    outHeaderStream << res.toLatin1().trimmed();
-    headerFile.close();
-#endif
+
     if (expfname.isNull()) {
         std::cout << res.toUtf8().data() << std::endl;
         return 0;
     } else {
         QFile expFile(expfname);
-        expFile.open(QIODevice::ReadOnly | QIODevice::Text);
+        expFile.open(QIODevice::ReadOnly);
         QByteArray expected = expFile.readAll();
         expFile.close();
         if (expected.trimmed() != res.toUtf8().trimmed()) {
